/* alt_to_rgb.c - A function to convert an altitude into RGB values
 *
 * Copyright (C) 2005 - 2006
 *                    Joern Wilms
 *                    Robert Dowse
 *                    Robert Swain
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include <math.h>
#include <stdlib.h>

#include "../druantia.h"
#include "imglib/imglib.h"

//FIXME fix me!

int alt_to_rgb(double alt, pixel_t *pixel) {

  // Return rgb value for a given altitude

  static unsigned char *ctable=NULL;  // color table
  static int minalt=0;      // minimum altitude (resp. depth...)
  static int maxalt=0;      // maximum altitude

  // Deal with 32767s
  if(alt == (double)-32767){
    pixel->r=0;
    pixel->g=0;
    pixel->b=0;
    return(OK);
  }

  if ( !ctable ) {
    // initialize color table
    // columns are: height, r, g, b
    int col[][4]={
//      {-12000,   0,   0,   0},  // black at -10km
//      { -6000,   0,   0,  80},  // Dim blue
//      { -2400,   0,   0, 255},  // -2400m: end of cont.shelf, blue
      {-12000,   0,   0, 200},  // black at -10km
      { -6000,  30,  75, 150},  // Dim blue
      { -2400,  64, 128, 255},  // -2400m: end of cont.shelf, blue
//      {  -200, 192, 192, 255},  // -200m: cont. shelf, brownish
      {  -200, 100, 150, 255},  // -200m: cont. shelf, brownish
      {     0, 150, 185, 255},  // almost white
//      {     1,  96, 172,  96},  // dark sea green
      {     1,  50, 100,  50},  // dark sea green
      {   100,  63, 124,  63},  // yellow green
//      {   100, 75,  150,  75},  // yellow green
      {   350, 172, 195, 112},  // brighter yellow
//      {   350, 100, 150,  75},  // brighter yellow
      {   500, 238, 195, 145},  // burlywood2
      {  1000, 205, 170, 125},  // burlywood3
      {  2000, 190, 133,  83},  // brownish
      {  4000, 139,  71,  38},  // sienna4
      {  5500, 250, 250, 250},  // almost White
      {  9000, 255, 255, 255}}; // white

#ifdef CMAP1
    int col[][4] = {
      { -9000,   0,   0,   0},  // Dark Gray at 0
      { -4900,   0,   0, 128},  // Dim blue
      { -1500,   0,   0, 255},  // Bright blue
      {   -40, 192, 192, 255},  // Brownish
      {     0,  64, 192,  64},  // Med green
      {   250, 150, 150,  75},  // Dim Yellow
      {  1000, 200, 200, 100},  // Brighter yellow
      {  4000, 255, 255, 255},  // White
      {  9000, 255, 255, 255}}; // To white
#endif

    int nrow=sizeof(col)/(4*sizeof(int));
    minalt=col[0][0];
    maxalt=col[nrow-1][0];

    // generate color for each height, using simple linear
    // interpolation in the rgb values
    ctable=(unsigned char *) malloc((maxalt-minalt+1)*sizeof(unsigned char)*3);

    int h;
    int i=0;
    int i1=1;

    for (h=minalt;h<=maxalt;h++) {
      int j,j1;
      for (j=0;j<3;j++) {
        j1=j+1;
        ctable[(h-minalt)*3+j] = (unsigned char) (col[i][j1]+
          (double)(h-col[i][0])/(double)(col[i1][0]-col[i][0])*
          (col[i1][j1]-col[i][j1]));
      }
      if(h == col[i1][0]){
        i++;
        i1++;
      }
    }
  }

  if(alt < minalt){ alt = minalt; }
  if(alt > maxalt){ alt = maxalt; }

  alt = (alt - minalt)*3;
  int ialt = (int)(alt + 0.5);
  pixel->r = ctable[ialt];
  pixel->g = ctable[ialt + 1];
  pixel->b = ctable[ialt + 2];

  return(OK);
}
