/* alt_to_rgb.c - A function to convert an altitude into RGB values
 *
 * Copyright (C) 2005 - 2006
 *                    Joern Wilms
 *                    Robert Dowse
 *                    Robert Swain
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include <math.h>
#include <stdlib.h>

#include "../druantia.h"
#include "imglib/imglib.h"

#define MOLA 1

int alt_to_rgb_mars(double alt, pixel_t *pixel) {

  // Return rgb value for a given altitude

  static unsigned char *ctable = NULL;  // color table
  static int minalt = 0;      // minimum altitude (resp. depth...)
  static int maxalt = 0;      // maximum altitude

  // Deal with 32767s
  if(alt == (double)-32767){
    pixel->r = 0;
    pixel->g = 0;
    pixel->b = 0;
    return(OK);
  }

  if(!ctable){
    // initialize color table
    // columns are: height, r, g, b
    // Mars: between -8208 and 21249m
#ifdef GRAY
    int col[][4] = {
      { -9000,   0,   0,   0},  // black
      { 22000, 255, 255, 255}   // white
    };
#endif
#ifdef MOLA
    int col[][4] = {
      { -9000,  56, 148,  52},  // dark blue at -8.5
      { -7500,  64,  60,  67},
      { -6000,  52,  80, 117},
      { -4000,   4, 161, 238},
      { -2500,  12, 255, 129},
      { -1000, 101, 242,   4},
      {     0, 255, 242,  28},
      {  1000, 225, 182,   4},
      {  2000, 250,  80,   4},
      {  3000, 246,  12,   4},
      {  4000, 230,  64,  12},
      {  5000, 170, 117,  40},
      {  6000, 145, 145, 145},
      { 22000, 255, 255, 255}   // white
    };
#endif
#ifdef ROB_COLOURPICKER
    int col[][4] = {
      { -9000,  78,  75,  68}, // browny grey
      { -2500, 125, 110,  81}, // dark beige
      {     0, 222, 184, 121}, // beige
      {  1000, 189, 169, 132}, // whispy grey brown
      { 22000, 120, 100,  64}  // brown
    };
#endif

    int nrow = sizeof(col) / (4*sizeof(int));
    minalt = col[0][0];
    maxalt = col[nrow-1][0];

    // generate color for each height, using simple linear
    // interpolation in the rgb values
    ctable = (unsigned char *)malloc((maxalt-minalt+1)*sizeof(unsigned char)*3);

    int h;
    int i = 0;
    int i1 = 1;

    for(h = minalt; h <= maxalt; h++){
      int j,j1;
      for(j=0; j<3; j++){
        j1 = j+1;
        ctable[(h-minalt)*3 + j] = (unsigned char)(col[i][j1]+
          (double)(h-col[i][0])/(double)(col[i1][0]-col[i][0])*
          (col[i1][j1]-col[i][j1]));
      }
      if(h == col[i1][0]){
        i++;
        i1++;
      }
    }
  }

  if(alt < minalt){ alt = minalt; }
  if(alt > maxalt){ alt = maxalt; }

  alt = (alt - minalt)*3;
  int ialt = (int)(alt + 0.5);
  pixel->r = ctable[ialt];
  pixel->g = ctable[ialt + 1];
  pixel->b = ctable[ialt + 2];

  return(OK);
}
