/* common.h - Useful structs and definitions for common functions
 *
 * Copyright (C) 2005 - 2006
 *                    Joern Wilms
 *                    Robert Dowse
 *                    Robert Swain
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include <inttypes.h>

#include "imglib/imglib.h"

#ifndef _COMMON_H
#define _COMMON_H

// lambda and phi coordinate struct
typedef struct {

  double lam, phi;

} coords_t;

// l1,l2,l3 horizon related lengths
// see get_horizon.c for more information
typedef struct {

  double l1, l2; //, l3;

} horizon_t;

// condense general properties into a struct
typedef struct {

  int width, height, planet, projection;
  double lam0, phi0, scale, dpi, rad_of_planet, deg_per_pix, cam_height, alt_factor;
  char *datapath, *pngpath;

} main_t;

#define EARTH 0
#define MARS 1

#define CYLINDER 0
#define SATELLITE 1

int druantia2d(main_t *main);
int druantia3d(main_t *main);
int get_lam_phi(main_t *main, int x, int y, coords_t *coords);
int get_lam_phi_satellite(main_t *main, int x, int y, coords_t *coords, double *cart);
int wrap_lam_phi(coords_t *coords);
int get_alt(coords_t *coords, char *datapath, short *alt);
int get_alt_mars(coords_t *coords, char *datapath, short *alt);
int alt_to_rgb(double alt, pixel_t *pixel);
int alt_to_rgb_mars(double alt, pixel_t *pixel);
double xyz_to_height(main_t *main, const double *_curpos);
int get_horizon(main_t *main, double cam_height, horizon_t *horizon);
void print_errno_info(int errnumber);

#endif
