/* get_horizon.c - A function to find the distance to the horizon from
 *                 a camera position above the image.
 *
 * Copyright (C) 2005 - 2006
 *                    Joern Wilms
 *                    Robert Dowse
 *                    Robert Swain
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <math.h>

#include "../druantia.h"
#include "common.h"

int get_horizon(main_t *main, double cam_height, horizon_t *horizon){

  // l1 = straight line distance from the camera to the horizon
  // l2 = perpendicular distance between the radial line through the camera and
  //  the horizon
  // l3 = the arclength from the footpoint to the horizon UNUSED as l2 is more appropriate

/*
  // the angle between the radial lines going through the camera and the horizon
  double angle = acos(main->rad_of_planet/(main->rad_of_planet + cam_height));
  printf("r = %f : h = %f\n", main->rad_of_planet, cam_height);

  horizon->l1 =  sin(angle)*(main->rad_of_planet + cam_height);
  horizon->l2 =  sin(angle)* main->rad_of_planet;
//  horizon->l3 =      angle * main->rad_of_planet;
*/

  double h_plus_r = cam_height + main->rad_of_planet;
  double r = main->rad_of_planet; // to reduce verbosity of code

  horizon->l1 = sqrt(cam_height*cam_height + 2.0*cam_height*r);
  horizon->l2 = sqrt(2.0*r*r*cam_height/h_plus_r - cam_height*cam_height*r*r/(h_plus_r*h_plus_r));

  return(OK);

}
